0.5.2
-----
* Fix serilazing of `kind` field in `Unit`.
* Fix on markdown.

0.5.1
-----
* Remove println statement.
* Fixes on markdown.

0.5.0
-----
* Replaced [roxmltree](https://github.com/RazrFalcon/roxmltree) in favor of [quick-xml](https://github.com/tafia/quick-xml/).
* Writing capabilities of `ModelRaw`.
* Huge improvement of documentation.
* Lost support of [MathML](https://github.com/jlricon/mathml/).

0.4.1
-----
* Added in-code README and automate README generation through cargo-readme

0.4.0
-----
* Added model.name and model.id
